@@ -12,23 +12,25 @@
 #include <string.h>
 #include <vector>
 #include <map>
+#include <sstream>
 #include "../Paramer.h"
 struct __attribute__((packed)) name_str{
-	long read_name;
+	long read_name; //needs to be a number to store in binary! (bit reservation!)
 	int svs_id;
 };
 struct combine_str{
 	int curr_id;
 	int alt_id;
 	int support;
+	short hit;
 };
 
 class Cluster_SVS{
 private:
 	std::map<long, std::vector<int> > parse_names_ids(int & max_ID) ;
 	void update_SVs( std::vector<combine_str> & ids); //just because the pass is more efficient
-	void add_id(int curr_id,int new_id, std::vector<combine_str> &  ids);
-	int find_id(int curr_id, std::vector<combine_str> & ids);
+	void add_id(int curr_id,int new_id, std::vector<combine_str> &  ids,int subkey);
+	std::string find_id(int curr_id, std::vector<combine_str> & ids);
 public:
 	Cluster_SVS(){
 	}
