@@ -15,26 +15,28 @@
 #include "Breakpoint.h"
 
 ///////////////////////////////// MERGING////////////////////////////////////////////
-std::string print_type(char SV1){
-	std::string type="";
-	if((SV1 & INS)){
-		type+= "INS";
+std::string print_type(char SV1) {
+	std::string type = "";
+	if ((SV1 & INS)) {
+		type += "INS";
 	}
-
-	if((SV1 & TRA)){
-		type+=  "TRA";
+	if ((SV1 & TRA)) {
+		type += "TRA";
 	}
-
-	if((SV1 & INV)){
-		type+=  "INV";
+	if ((SV1 & INV)) {
+		type += "INV";
 	}
-
-	if((SV1 & DEL)){
-		type+=  "DEL";
+	if ((SV1 & DEL)) {
+		type += "DEL";
 	}
-
-	if((SV1 & DUP)){
-		type+=  "DUP";
+	if ((SV1 & DUP)) {
+		type += "DUP";
+	}
+	if ((SV1 & NEST)) {
+		type += "INVDUP";
+	}
+	if ((SV1 & NEST)) {
+		type += "INS_open";
 	}
 	return type;
 }
@@ -53,136 +55,164 @@ bool Breakpoint::check_SVtype(Breakpoint * break1, Breakpoint * break2) { //todo
 		return true;
 	} else if ((SV1 & DEL) && (SV2 & DEL)) {
 		return true;
-	} //else if (((SV1 & DUP) && (SV2 & INS)) || ((SV1 & INS) && (SV2 & DUP))) {
+	} else if (((SV1 & NEST) && (SV2 & NEST)) || (((SV1 & NEST) && (SV2 & INV)) || ((SV1 & INV) && (SV2 & NEST)))) {
+		return true;
+	}
+	//else if (((SV1 & DUP) && (SV2 & INS)) || ((SV1 & INS) && (SV2 & DUP))) {
 	//	return true;
 	//}
 	//std::cout<<"S1: "<<print_type(SV1)<<" S2 "<<print_type(SV2)<<" "<<(*break2->get_coordinates().support.begin()).second.type<<std::endl;
-	return false;
+	return (SV1 == SV2);
 }
 bool Breakpoint::is_same_strand(Breakpoint * tmp) {
 	//todo check for same SVtype? except for INV+DEL
 	if (check_SVtype(tmp, this)) {
-		if ((*tmp->get_coordinates().support.begin()).second.SV & TRA) { //only for tra since we get otherwise a problem with the cigar events
-			return ((*tmp->get_coordinates().support.begin()).second.strand.first == (*this->get_coordinates().support.begin()).second.strand.first && (*tmp->get_coordinates().support.begin()).second.strand.second == (*this->get_coordinates().support.begin()).second.strand.second);
-		}
+
+		//if ((*tmp->get_coordinates().support.begin()).second.SV & TRA) { //only for tra since we get otherwise a problem with the cigar events
+		//	//std::string readname= (*tmp->get_coordinates().support.begin()).first;
+		//	return ((*tmp->get_coordinates().support.begin()).second.strand.first == (*this->get_coordinates().support.begin()).second.strand.first && (*tmp->get_coordinates().support.begin()).second.strand.second == (*this->get_coordinates().support.begin()).second.strand.second);
+		//}
 		return true;
 	}
 	return false;
 }
 int get_dist(Breakpoint * tmp) {
-
 	position_str pos = tmp->get_coordinates();
+
 	//return Parameter::Instance()->max_dist;
-	if ((*tmp->get_coordinates().support.begin()).second.SV & TRA || (*tmp->get_coordinates().support.begin()).second.SV & INS) {
+
+	if ((*tmp->get_coordinates().support.begin()).second.SV & TRA) {
 		return Parameter::Instance()->max_dist; //TODO: change!
-	} else {
-		int max_val = Parameter::Instance()->max_dist; // * 0.5; //TOOD maybe 0.5?
-		return std::max(std::min((int) (pos.stop.max_pos - pos.start.min_pos) / 80, Parameter::Instance()->max_dist), max_val); //20% of the lenght of the SV
 	}
+	long dist = (pos.stop.max_pos - pos.start.min_pos);
+
+	if ((*pos.support.begin()).second.length != 1) {
+		dist = (*pos.support.begin()).second.length;
+	}
+
+	/*	if(dist<10){
+	 std::cout<<"DIST <10 ! "<<dist <<std::endl;
+	 }*/
+	dist = std::max((long) Parameter::Instance()->min_length * 2, dist);
+
+	/*if(dist <10){//TODO
+	 dist=(long)Parameter::Instance()->max_dist;
+	 std::cout<<"LEN SMALLER! "<<(*pos.support.begin()).first<<" "<<Parameter::Instance()->max_dist<<" "<<(pos.stop.max_pos - pos.start.min_pos)<< std::endl;
+	 }*/
+	return std::min((int) (dist * 4), Parameter::Instance()->max_dist);
 }
 
 long Breakpoint::overlap(Breakpoint * tmp) {
 	bool flag = false;
-
-	int max_dist = Parameter::Instance()->max_dist; // get_dist(tmp);
+//flag = ((*tmp->get_coordinates().support.begin()).second.SV & DEL);
+	int max_dist = std::min(get_dist(tmp), get_dist(this)); // Parameter::Instance()->max_dist
 	if (flag) {
-		std::cout << "\t Overlap: " << max_dist << " start: " << abs(tmp->get_coordinates().start.min_pos - positions.stop.min_pos) << " stop :" << abs(tmp->get_coordinates().stop.max_pos - positions.start.max_pos);
-		if(is_same_strand(tmp) ){
-			std::cout<<"same strand";
+		std::cout << "\t Overlap: " << max_dist << " start: " << tmp->get_coordinates().start.min_pos << " " << positions.start.min_pos << " stop :" << tmp->get_coordinates().stop.max_pos << " " << positions.stop.max_pos;
+		if ((*positions.support.begin()).second.SV & DEL) {
+			std::cout << " Is DEL";
+		} else if ((*positions.support.begin()).second.SV & INS) {
+			std::cout << " Is Ins ";
+		} else if ((*positions.support.begin()).second.SV & DUP) {
+			std::cout << " Is Dup ";
+		} else if ((*positions.support.begin()).second.SV & INV) {
+			std::cout << " Is Inv ";
 		}
+		std::cout << " Support: " << positions.support.size();
+		std::cout << std::endl;
+
 	}
-	//check type. ALN could be part of the SPlit read event! Not merge two split reads!
+//merging two robust calls:
+
 	if (is_same_strand(tmp) && (abs(tmp->get_coordinates().start.min_pos - positions.start.min_pos) < max_dist && abs(tmp->get_coordinates().stop.max_pos - positions.stop.max_pos) < max_dist)) {
 		if (flag) {
-			std::cout << "\t hit!" << std::endl;
-
+			cout << "\tHIT" << endl;
 		}
 		return 0;
 	}
 
-	//TODO:: if one of the two SVs is based on ALN it might be good to join them: to merge noisy flanking regions
-	if (((tmp->get_types().is_ALN || this->get_types().is_ALN) && !(tmp->get_types().is_ALN && this->get_types().is_ALN)) && (abs(tmp->get_coordinates().start.min_pos - positions.stop.min_pos) < max_dist / 2 || abs(tmp->get_coordinates().stop.max_pos - positions.start.max_pos) < max_dist / 2)) { //TODO maybe add SV type check!
-		if (flag) {
-			std::cout << "\t hit!" << std::endl;
-		}
+	if ((is_NEST(tmp, this) && is_same_strand(tmp)) && (abs(tmp->get_coordinates().start.min_pos - positions.start.min_pos) < Parameter::Instance()->max_dist || abs(tmp->get_coordinates().start.min_pos - positions.stop.min_pos) < Parameter::Instance()->max_dist)) {
 		return 0;
 	}
-	if (flag) {
-		std::cout << "no hit? " << std::endl;
-	}
+//extend Split read by noisy region: //not longer needed??
+	/*	if (((tmp->get_types().is_Noise || this->get_types().is_Noise) && !(tmp->get_types().is_Noise && this->get_types().is_Noise))
+	 && (abs(tmp->get_coordinates().start.min_pos - positions.stop.min_pos) < max_dist / 2 || abs(tmp->get_coordinates().stop.max_pos - positions.start.max_pos) < max_dist / 2)) { //TODO maybe add SV type check!
+	 if (flag) {
+	 cout << "\tHIT Noise" << endl;
+	 }
+	 return 0;
+	 }*/
 
 //as abstraction lets try the start+stop coordinate!
 	long diff = (tmp->get_coordinates().start.min_pos - positions.start.min_pos);
-	if (abs(diff) < max_dist) {
-		return (tmp->get_coordinates().stop.max_pos - positions.stop.max_pos);
+//if (abs(diff) < max_dist) {
+//return (tmp->get_coordinates().stop.max_pos - positions.stop.max_pos);
+//}
+	if (diff == 0) {
+		return 1;
 	}
 	return diff; // + (tmp->get_coordinates().stop.max_pos - positions.stop.max_pos);
 }
 
-void Breakpoint::add_read(Breakpoint * point) {
+void Breakpoint::add_read(Breakpoint * point) { //point = one read support!
+
 	if (point != NULL) {
-		if ((*point->get_coordinates().support.begin()).second.type == 0) {
-			this->type.is_ALN = true;
-		}
-		if ((*point->get_coordinates().support.begin()).second.type == 1) {
-			this->type.is_SR = true;
-		}
+		/*if ((*point->get_coordinates().support.begin()).second.type == 0) {
+		 this->type.is_ALN = true;
+		 }
+		 if ((*point->get_coordinates().support.begin()).second.type == 1) {
+		 this->type.is_SR = true;
+		 }
 
-		if ((point->get_types().is_ALN || this->get_types().is_ALN) && !(point->get_types().is_ALN && this->get_types().is_ALN)) { //
-			this->type.is_ALN = false; //TODO trick ;)
-			//THis is to merger noisy flanking regions:
-			if (abs(point->get_coordinates().start.min_pos - positions.stop.min_pos) < Parameter::Instance()->max_dist / 2) { //left of the current position
-			//start stays; stop changes
-				this->positions.stop.min_pos = positions.stop.min_pos;
-				this->positions.stop.max_pos = positions.stop.max_pos;
-				//Now we make the stop positions invalid:
-				std::map<std::string, read_str> support = this->positions.support;
-				for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
-					(*i).second.coordinates.second = -1;
-				}
-				support = point->get_coordinates().support;
-				for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
-					(*i).second.coordinates.second = -1;
-				}
-			} else if (abs(point->get_coordinates().stop.max_pos - positions.start.max_pos) < Parameter::Instance()->max_dist / 2) { //right of the current position
-			//	cout << "right " << endl;
-			//stop stays; start changes:
-				this->positions.start.min_pos = positions.start.min_pos;
-				this->positions.start.max_pos = positions.start.max_pos;
+		 if ((point->get_types().is_ALN || this->get_types().is_ALN) && !(point->get_types().is_ALN && this->get_types().is_ALN)) { //just to extend a split read event
+		 this->type.is_ALN = false; //TODO trick ;)
+		 //THis is to merger noisy flanking regions:
+		 if (abs(point->get_coordinates().start.min_pos - positions.stop.min_pos) < Parameter::Instance()->max_dist / 2) { //left of the current position
+		 //start stays; stop changes
+		 this->positions.stop.min_pos = positions.stop.min_pos;
+		 this->positions.stop.max_pos = positions.stop.max_pos;
+		 //Now we make the stop positions invalid:
+		 std::map<std::string, read_str> support = this->positions.support;
+		 for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
+		 (*i).second.coordinates.second = -1;
+		 }
+		 support = point->get_coordinates().support;
+		 for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
+		 (*i).second.coordinates.second = -1;
+		 }
+		 } else if (abs(point->get_coordinates().stop.max_pos - positions.start.max_pos) < Parameter::Instance()->max_dist / 2) { //right of the current position
+		 //	cout << "right " << endl;
+		 //stop stays; start changes:
+		 this->positions.start.min_pos = positions.start.min_pos;
+		 this->positions.start.max_pos = positions.start.max_pos;
 
-				//Now we make the start positions invalid:
-				std::map<std::string, read_str> support = this->positions.support;
-				for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
-					(*i).second.coordinates.first = -1;
-				}
-				support = point->get_coordinates().support;
-				for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
-					(*i).second.coordinates.first = -1;
-				}
-			}
-		} else {
-			this->positions.start.min_pos = min(this->positions.start.min_pos, point->get_coordinates().start.min_pos);
-			this->positions.start.max_pos = max(this->positions.start.max_pos, point->get_coordinates().start.max_pos);
+		 //Now we make the start positions invalid:
+		 std::map<std::string, read_str> support = this->positions.support;
+		 for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
+		 (*i).second.coordinates.first = -1;
+		 }
+		 support = point->get_coordinates().support;
+		 for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
+		 (*i).second.coordinates.first = -1;
+		 }
+		 }
+		 } else {			// merge two events:
+		 //grow interval:
+		 //	this->positions.start.min_pos = min(this->positions.start.min_pos, point->get_coordinates().start.min_pos);
+		 //	this->positions.start.max_pos = max(this->positions.start.max_pos, point->get_coordinates().start.max_pos);
 
-			if (point->get_coordinates().support.begin()->second.SV & INS) {
-				this->positions.stop.min_pos = this->positions.start.max_pos;
-				this->positions.stop.max_pos = this->positions.start.max_pos;
-			} else {
-				this->positions.stop.min_pos = min(this->positions.stop.min_pos, point->get_coordinates().stop.min_pos);
-				this->positions.stop.max_pos = max(this->positions.stop.max_pos, point->get_coordinates().stop.max_pos);
-			}
-		}
-		bool flag = false;
+		 /*	if (point->get_coordinates().support.begin()->second.SV & INS) {
+		 this->positions.stop.min_pos = this->positions.start.max_pos;
+		 this->positions.stop.max_pos = this->positions.start.max_pos;
+		 } else {
+		 this->positions.stop.min_pos = min(this->positions.stop.min_pos, point->get_coordinates().stop.min_pos);
+		 this->positions.stop.max_pos = max(this->positions.stop.max_pos, point->get_coordinates().stop.max_pos);
+		 }
+		 }*/
+		//merge the support:
 		std::map<std::string, read_str> support = point->get_coordinates().support;
 		for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
-			if (this->positions.support[(*i).first].SV & INS) {
-				flag = true;
-			}
 			this->positions.support[(*i).first] = (*i).second;
 		}
-		if (flag) {
-			this->length = (this->length + point->get_length()) / 2;
-		}
 	}
 }
 
@@ -198,8 +228,8 @@ std::vector<std::string> Breakpoint::get_read_names(int maxim) {
 	return read_names;
 }
 
-std::vector<int> Breakpoint::get_read_ids() {
-	std: vector<int> read_names;
+std::vector<long> Breakpoint::get_read_ids() {
+	std: vector<long> read_names;
 	std::map<std::string, read_str> support = this->positions.support;
 	int num = 0;
 	for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
@@ -225,7 +255,7 @@ std::string Breakpoint::translate_strand(pair<bool, bool> strand_pair) {
 }
 
 void Breakpoint::summarize_type(char SV, std::vector<short>& array) {
-	//std::string ss;
+//std::string ss;
 	if (SV & DEL) {
 		//	ss += "DEL; ";
 		array[0]++;
@@ -250,13 +280,17 @@ void Breakpoint::summarize_type(char SV, std::vector<short>& array) {
 		//	ss += "TRA; ";
 		array[4]++;
 	}
-	//return ss;
+	if (SV & NEST) {
+		//	ss += "NEST; ";
+		array[5]++;
+	}
+//return ss;
 }
 
 char Breakpoint::get_SVtype() {
 
-	if (sv_type == ' ') {
-		std::cerr << "was not set" << std::endl;
+	if (sv_type & NA) {
+//		std::cerr << "was not set" << std::endl;
 		calc_support();
 		predict_SV();
 	}
@@ -264,22 +298,21 @@ char Breakpoint::get_SVtype() {
 }
 
 void Breakpoint::calc_support() {
-	//if (positions.support.size() > Parameter::Instance()->min_support) {
 	std::vector<short> SV;
-	for (size_t i = 0; i < 5; i++) {
+	for (size_t i = 0; i < 6; i++) {
 		SV.push_back(0);
 	}
-	//run over all supports and check the majority type:
+//run over all supports and check the majority type:
 	for (std::map<std::string, read_str>::iterator i = positions.support.begin(); i != positions.support.end(); i++) {
 		summarize_type((*i).second.SV, SV);
 	}
-	//given the majority type get the stats:
+//given the majority type get the stats:
 	this->sv_type = eval_type(SV);
-	//}
+
 }
 
 char Breakpoint::eval_type(std::vector<short> SV) {
-	/*	std::stringstream ss;
+	/*std::stringstream ss;
 	 if (SV[0] != 0) {
 	 ss << " DEL(";
 	 ss << SV[0];
@@ -306,8 +339,8 @@ char Breakpoint::eval_type(std::vector<short> SV) {
 	 ss << ")";
 	 }
 	 this->sv_debug = ss.str(); //only for debug!
-	 std::cout << sv_debug << std::endl;
-	 */
+	 std::cout << sv_debug << std::endl;*/
+
 	int maxim = 0;
 	int id = 0;
 	for (size_t i = 0; i < SV.size(); i++) {
@@ -332,17 +365,32 @@ char Breakpoint::eval_type(std::vector<short> SV) {
 	if (maxim == SV[4]) {
 		max_SV |= TRA;
 	}
-
+	if (maxim == SV[5]) {
+		max_SV |= NEST;
+	}
 	return max_SV;
 }
 
+long get_median(std::vector<long> corrds) {
+	sort(corrds.begin(), corrds.end());
+	if (corrds.size() % 2 == 0) {
+		return (corrds[corrds.size() / 2 - 1] + corrds[corrds.size() / 2]) / 2;
+	}
+	return corrds[corrds.size() / 2];
+
+}
 void Breakpoint::predict_SV() {
 	bool aln = false;
 	bool split = false;
+	bool noise = false;
 	int num = 0;
 	std::map<long, int> starts;
 	std::map<long, int> stops;
+	std::map<long, int> lengths;			//ins!
 	std::map<std::string, int> strands;
+	std::vector<long> start2;
+	std::vector<long> stops2;
+	std::vector<long> lengths2;
 
 	for (std::map<std::string, read_str>::iterator i = positions.support.begin(); i != positions.support.end(); i++) {
 		if ((*i).second.SV & this->sv_type) { ///check type
@@ -353,6 +401,7 @@ void Breakpoint::predict_SV() {
 				} else {
 					starts[(*i).second.coordinates.first]++;
 				}
+				start2.push_back((*i).second.coordinates.first);
 			}
 			if ((*i).second.coordinates.second != -1) { //TODO test
 				if (stops.find((*i).second.coordinates.second) == stops.end()) {
@@ -360,12 +409,21 @@ void Breakpoint::predict_SV() {
 				} else {
 					stops[(*i).second.coordinates.second]++;
 				}
+				stops2.push_back((*i).second.coordinates.second);
 			}
+			if ((*i).second.SV & INS) { //check lenght for ins only!
+				//	std::cout<<"LENGTH 1st: "<<(*i).second.length<<" "<<(*i).first<<std::endl;
+				if (lengths.find((*i).second.length) == lengths.end()) {
+					lengths[(*i).second.length] = 1;
+				} else {
+
+					lengths[(*i).second.length]++;
+				}
+				lengths2.push_back((*i).second.length);
+			}
+
 			if (!((*i).second.type == 0 && ((*i).second.SV & INV))) {
-
 				std::string tmp = translate_strand((*i).second.strand);
-
-				//std::cout << tmp << std::endl;
 				if (strands.find(tmp) == strands.end()) {
 					strands[tmp] = 1;
 				} else {
@@ -376,6 +434,8 @@ void Breakpoint::predict_SV() {
 				aln = true;
 			} else if ((*i).second.type == 1) {
 				split = true;
+			} else if ((*i).second.type == 2) {
+				noise = true;
 			} else {
 				std::cerr << "Type " << (*i).second.type << std::endl;
 			}
@@ -387,17 +447,18 @@ void Breakpoint::predict_SV() {
 	long counts = 0;
 	int maxim = 0;
 	long coord = 0;
+
 	for (map<long, int>::iterator i = starts.begin(); i != starts.end(); i++) {
-		//cout<<"start:\t"<<(*i).first<<" "<<(*i).second<<endl;
+		//	cout << "start:\t" << (*i).first << " " << (*i).second << endl;
 		if ((*i).second > maxim) {
 			coord = (*i).first;
 			maxim = (*i).second;
 		}
-		mean += ((*i).first * (*i).second);
-		counts += (*i).second;
+		//mean += ((*i).first * (*i).second);
+		//	counts += (*i).second;
 	}
 	if (maxim < 5) {
-		this->positions.start.most_support = mean / counts;
+		this->positions.start.most_support = get_median(start2);	//mean / counts;
 	} else {
 		this->positions.start.most_support = coord;
 	}
@@ -407,21 +468,48 @@ void Breakpoint::predict_SV() {
 	mean = 0;
 	counts = 0;
 	for (map<long, int>::iterator i = stops.begin(); i != stops.end(); i++) {
+		//	cout << "stop:\t" << (*i).first << " " << (*i).second << endl;
 		if ((*i).second > maxim) {
 			coord = (*i).first;
 			maxim = (*i).second;
 		}
-		mean += ((*i).first * (*i).second);
-		counts += (*i).second;
+		//mean += ((*i).first * (*i).second);
+		//	counts += (*i).second;
 	}
 	if (maxim < 5) {
-		this->positions.stop.most_support = mean / counts;
+		this->positions.stop.most_support = get_median(stops2);	// mean / counts;
 	} else {
 		this->positions.stop.most_support = coord;
 	}
-	if (!(this->get_SVtype() & INS)) {
+	/*if(this->get_SVtype() & NEST){
+	 this->length = -1;
+	 }else
+	 */
+
+	if (!(this->get_SVtype() & INS)) { //all types but Insertions:
 		this->length = this->positions.stop.most_support - this->positions.start.most_support;
+	} else { //compute most supported length for insertions:
+		maxim = 0;
+		coord = 0;
+		mean = 0;
+		counts = 0;
+		for (map<long, int>::iterator i = lengths.begin(); i != lengths.end(); i++) {
+			//	std::cout<<"LENGTH: "<<(*i).first<<" : "<<(*i).second<<std::endl;
+			if ((*i).second > maxim) {
+				coord = (*i).first;
+				maxim = (*i).second;
+			}
+			//	mean += ((*i).first * (long) (*i).second);
+			//	counts += (*i).second;
+		}
+		if (maxim < 3) {
+			this->length = get_median(lengths2);
+		} else {
+			this->length = coord;
+		}
+
 	}
+
 	starts.clear();
 	stops.clear();
 
@@ -444,14 +532,23 @@ void Breakpoint::predict_SV() {
 
 	this->supporting_types = "";
 	if (aln) {
+		this->type.is_ALN = true;
 		this->supporting_types += "AL";
 	}
 	if (split) {
+		this->type.is_SR = true;
 		if (!supporting_types.empty()) {
 			this->supporting_types += ",";
 		}
 		this->supporting_types += "SR";
 	}
+	if (noise) {
+		this->type.is_Noise = true;
+		if (!supporting_types.empty()) {
+			this->supporting_types += ",";
+		}
+		this->supporting_types += "NR";
+	}
 }
 
 std::string Breakpoint::get_chr(long pos, RefVector ref) {
@@ -510,7 +607,7 @@ std::string Breakpoint::get_strand(int num_best) {
 //if(this->strand.empty()){
 //	predict_SV();
 //}
-	if (sv_type == ' ') {
+	if (sv_type & NA) {
 		//	std::cout<<"was not set"<<std::endl;
 		calc_support();
 		predict_SV();
@@ -532,16 +629,20 @@ std::string Breakpoint::get_strand(int num_best) {
 #include "Detect_Breakpoints.h"
 std::string Breakpoint::to_string() {
 	std::stringstream ss;
-	ss << "\t\tTREE: ";
-	ss << TRANS_type(this->get_SVtype());
-	ss << " ";
-	ss << get_coordinates().start.min_pos;
-	ss << ":";
-	ss << get_coordinates().stop.max_pos;
-	ss << " ";
-	ss << positions.support.size();
-	ss << " ";
-	ss << get_strand(2);
+	if (positions.support.size() > 1) {
+		ss << "\t\tTREE: ";
+		ss << TRANS_type(this->get_SVtype());
+		ss << " ";
+		ss << get_coordinates().start.min_pos;
+		ss << ":";
+		ss << get_coordinates().stop.max_pos;
+		ss << " ";
+		ss << this->length;
+		ss << " ";
+		ss << positions.support.size();
+		ss << " ";
+		ss << get_strand(2);
+	}
 	return ss.str();
 }
 std::string Breakpoint::to_string(RefVector ref) {
