@@ -6,6 +6,97 @@
  */
 
 #include "Detect_Breakpoints.h"
+#include "../print/IPrinter.h"
+
+long fuck_off(long pos, RefVector ref, std::string &chr) {
+	size_t i = 0;
+	pos -= (ref[i].RefLength + Parameter::Instance()->max_dist);
+
+	while (i < ref.size() && pos >= 0) {
+		i++;
+		pos -= ((long) ref[i].RefLength + (long) Parameter::Instance()->max_dist);
+	}
+	chr = ref[i].RefName;
+	return pos + ref[i].RefLength + (long) Parameter::Instance()->max_dist;
+}
+void store_pos(vector<hist_str> &positions, long pos, std::string read_name) {
+	for (size_t i = 0; i < positions.size(); i++) {
+		if (abs(positions[i].position - pos) < Parameter::Instance()->min_length) {
+			positions[i].hits++;
+			positions[i].names.push_back(read_name);
+			return;
+		}
+	}
+	hist_str tmp;
+	tmp.position = pos;
+	tmp.hits = 1;
+	tmp.names.push_back(read_name);
+	positions.push_back(tmp);
+}
+
+Breakpoint * split_points(vector<std::string> names, std::map<std::string, read_str> support) {
+	std::map<std::string, read_str> new_support;
+	for (size_t i = 0; i < names.size(); i++) {
+		new_support[names[i]] = support[names[i]];
+	}
+	position_str svs;
+	svs.start.min_pos = 0;//just to initialize. Should not be needed anymore at this stage of the prog.
+	svs.stop.max_pos = 0;
+	svs.support = new_support;
+	Breakpoint * point = new Breakpoint(svs, (*new_support.begin()).second.coordinates.second - (*new_support.begin()).second.coordinates.first);
+	return point;
+}
+
+void detect_merged_svs(position_str point, RefVector ref, vector<Breakpoint *> & new_points) {
+	new_points.clear(); //just in case!
+	vector<hist_str> pos_start;
+	vector<hist_str> pos_stop;
+
+	for (std::map<std::string, read_str>::iterator i = point.support.begin(); i != point.support.end(); i++) {
+		long pos = (*i).second.coordinates.first;
+		//std::cout<<(*i).second.coordinates.first<<" "<<(*i).second.coordinates.second<<std::endl;
+		store_pos(pos_start, pos, (*i).first);
+		pos = (*i).second.coordinates.second;
+		store_pos(pos_stop, pos, (*i).first);
+	}
+//	std::cout << "Start: " << std::endl;
+	int start_count = 0;
+	for (size_t i = 0; i < pos_start.size(); i++) {
+		if (pos_start[i].hits > Parameter::Instance()->min_support) {
+			start_count++;
+			/*		std::string chr = "";
+			long pos = fuck_off(pos_start[i].position, ref, chr);
+			std::cout << chr << " " << pos << ":" << pos_start[i].hits << " ; ";
+			*/
+		}
+	}
+//	std::cout << std::endl;
+//	std::cout << "Stop: " << std::endl;
+	int stop_count = 0;
+	for (size_t i = 0; i < pos_stop.size(); i++) {
+		if (pos_stop[i].hits > Parameter::Instance()->min_support) {
+			stop_count++;
+		/*	std::string chr = "";
+			long pos = fuck_off(pos_stop[i].position, ref, chr);
+			std::cout << chr << " " << pos << ":" << pos_stop[i].hits << " ; ";
+			*/
+		}
+	}
+//	std::cout << std::endl;
+//	std::cout << std::endl;
+
+	if (stop_count > 1 || start_count > 1) {
+		std::cout << "\tprocessing merged TRA" << std::endl;
+		if (start_count > 1) {
+			new_points.push_back(split_points(pos_start[0].names, point.support));
+			new_points.push_back(split_points(pos_start[1].names, point.support));
+		} else {
+			new_points.push_back(split_points(pos_stop[0].names, point.support));
+			new_points.push_back(split_points(pos_stop[1].names, point.support));
+		}
+	}
+}
+
 std::string TRANS_type(char type) {
 	string tmp;
 	if (type & DEL) {
@@ -35,7 +126,12 @@ std::string TRANS_type(char type) {
 		}
 		tmp += "TRA";
 	}
-
+	if (type & NEST) {
+		if (!tmp.empty()) {
+			tmp += '/';
+		}
+		tmp += "NEST";
+	}
 	return tmp; // should not occur!
 }
 
@@ -50,33 +146,47 @@ long get_ref_lengths(int id, RefVector ref) {
 
 bool should_be_stored(Breakpoint *& point) {
 	point->calc_support(); // we need that before:
+	//std::cout << "Stored: " << point->get_support() << " " << point->get_length() << std::endl;
 	if (point->get_SVtype() & TRA) { // we cannot make assumptions abut support yet.
 		return (point->get_support() > 2); // this is needed as we take each chr independently and just look at the primary alignment
-	} else if (point->get_support() > Parameter::Instance()->min_support) {
+	} else if (point->get_support() >= Parameter::Instance()->min_support) {
 		point->predict_SV();
-		return (point->get_support() > Parameter::Instance()->min_support && point->get_length() > Parameter::Instance()->min_length);
+		return (point->get_support() >= Parameter::Instance()->min_support && point->get_length() > Parameter::Instance()->min_length);
 	}
 
 	return false;
 }
-/*
- void flush_tree(IntervallTree & local_tree, TNode *& local_root, IntervallTree & final, TNode *& root_final, long pos) {
- IntervallTree tmp_tree;
- TNode *tmp_root = NULL;
- std::vector<Breakpoint *> points;
- local_tree.get_breakpoints(local_root, points);
- clarify(points);
- for (int i = 0; i < points.size(); i++) {
- if (abs(pos - points[i]->get_coordinates().start.min_pos) < 100000 || abs(pos - points[i]->get_coordinates().stop.max_pos) < 100000) { //TODO arbitrary threshold!
- tmp_tree.insert(points[i], tmp_root);
- } else if (points[i]->get_support() > Parameter::Instance()->min_support && points[i]->get_length() > Parameter::Instance()->min_length) {
- final.insert(points[i], root_final);
- }
- }
- local_tree.makeempty(local_root);
- local_tree = tmp_tree;
- local_root = tmp_root;
- }*/
+void polish_points(std::vector<Breakpoint *> & points, RefVector ref) { //TODO might be usefull! but why does the tree not fully work??
+	return;
+	if (!points.empty()) {
+
+		for (size_t i = 0; i < points.size(); i++) {
+			points[i]->predict_SV();
+			points[i]->calc_support();
+		}
+
+		for (size_t i = 0; i < points.size(); i++) {
+			if (!(points[i]->get_SVtype() & TRA)) { // we cannot make assumptions abut support yet.
+				for (size_t j = 0; j < points.size(); j++) {
+					if (!(points[j]->get_SVtype() & TRA)) {
+						if ((i != j)
+								&& (abs(points[j]->get_coordinates().start.most_support - points[i]->get_coordinates().start.most_support) < Parameter::Instance()->max_dist / 2
+										&& abs(points[j]->get_coordinates().stop.most_support - points[i]->get_coordinates().stop.most_support) < Parameter::Instance()->max_dist / 2)) {
+
+							std::string chr;
+							int pos1 = fuck_off(points[j]->get_coordinates().start.most_support, ref, chr);
+							std::cout << "HIT: " << chr << " " << pos1 << " " << TRANS_type((*points[j]->get_coordinates().support.begin()).second.SV) << " OTHER: ";
+
+							pos1 = fuck_off(points[i]->get_coordinates().start.most_support, ref, chr);
+
+							std::cout << chr << " " << pos1 << " " << TRANS_type((*points[i]->get_coordinates().support.begin()).second.SV) << std::endl;
+						}
+					}
+				}
+			}
+		}
+	}
+}
 
 void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 	estimate_parameters(read_filename);
@@ -94,15 +204,20 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 	std::cout << "Start parsing..." << std::endl;
 //Using Interval tree to store and manage breakpoints:
 
+	//IntervallList final;
+	//IntervallList bst;
+
 	IntervallTree final;
+	IntervallTree bst;
+
 	TNode * root_final = NULL;
 	int current_RefID = 0;
 
-	IntervallTree bst;
 	TNode *root = NULL;
-	//FILE * alt_allel_reads;
+//FILE * alt_allel_reads;
 	FILE * ref_allel_reads;
 	if (Parameter::Instance()->genotype) {
+
 		std::string output = Parameter::Instance()->tmp_file.c_str();
 		output += "ref_allele";
 		ref_allel_reads = fopen(output.c_str(), "wb");
@@ -113,21 +228,23 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 	}
 	Alignment * tmp_aln = mapped_file->parseRead(Parameter::Instance()->min_mq);
 	long ref_space = get_ref_lengths(tmp_aln->getRefID(), ref);
-	std::string prev = "test";
-	std::string curr = "wtf";
+	//std::string prev = "test";
+	//std::string curr = "curr";
 	long num_reads = 0;
 	while (!tmp_aln->getQueryBases().empty()) {
 		if ((tmp_aln->getAlignment()->IsPrimaryAlignment()) && (!(tmp_aln->getAlignment()->AlignmentFlag & 0x800) && tmp_aln->get_is_save())) {
-			//flush_tree(local_tree, local_root, final, root_final);
-			if (current_RefID != tmp_aln->getRefID()) {	// Regular scan through the SV and move those where the end point lies far behind the current pos or reads. Eg. 1MB?
+			//change CHR:
+			if (current_RefID != tmp_aln->getRefID()) {
 				current_RefID = tmp_aln->getRefID();
 				ref_space = get_ref_lengths(tmp_aln->getRefID(), ref);
 				std::cout << "\tSwitch Chr " << ref[tmp_aln->getRefID()].RefName << " " << ref[tmp_aln->getRefID()].RefLength << std::endl;
 				std::vector<Breakpoint *> points;
 				//	clarify(points);
 				bst.get_breakpoints(root, points);
+				polish_points(points, ref);
 				for (int i = 0; i < points.size(); i++) {
 					if (should_be_stored(points[i])) {
+						//detect_merged_svs(points[i]);
 						if (points[i]->get_SVtype() & TRA) {
 							final.insert(points[i], root_final);
 						} else {
@@ -135,8 +252,9 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 						}
 					}
 				}
-				bst.makeempty(root);
+				bst.clear(root);
 			}
+			//SCAN read:
 			std::vector<str_event> aln_event;
 			std::vector<aln_str> split_events;
 			if (tmp_aln->getMappingQual() > Parameter::Instance()->min_mq) {
@@ -163,6 +281,7 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 				}
 				//tmp_aln->set_supports_SV(aln_event.empty() && split_events.empty());
 
+				//Store reference supporting reads for genotype estimation:
 				str_read tmp;
 				tmp.SV_support = !(aln_event.empty() && split_events.empty());
 				if ((Parameter::Instance()->genotype && !tmp.SV_support) && (score == -1 || score > Parameter::Instance()->score_treshold)) {
@@ -173,73 +292,66 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 					tmp.SV_support = false;
 					fwrite(&tmp, sizeof(struct str_read), 1, ref_allel_reads);
 				}
-				/*else { // we store the reads that support the SVs in IPrinter when writing out the SVs.
-				 for (size_t i = 0; i < split_events.size(); i++) {
-				 tmp.chr = ref[split_events[i].RefID].RefName;
-				 tmp.start = split_events[i].pos;
-				 tmp.length = split_events[i].length;
-				 fwrite(&tmp, sizeof(struct str_read), 1, alt_allel_reads);
-				 }
-				 if (split_events.empty()) { //splits store the primary aln as well!
-				 tmp.chr = ref[tmp_aln->getRefID()].RefName;
-				 tmp.start = tmp_aln->getPosition();
-				 tmp.length = tmp_aln->getRefLength();
-				 fwrite(&tmp, sizeof(struct str_read), 1, alt_allel_reads);
-				 }
-				 }*/
 
-				//	clock_t begin = clock();
-				//maybe just store the extreme intervals for coverage -> If the cov doubled within Xbp or were the coverage is 0.
+				//store the potential SVs:
 				if (!aln_event.empty()) {
 					add_events(tmp_aln, aln_event, 0, ref_space, bst, root, num_reads);
 				}
-				//	Parameter::Instance()->meassure_time(begin, " add event ");
-				//cout<<"event: "<<aln_event.size()<<endl;
-				//	begin = clock();
 				if (!split_events.empty()) {
 					add_splits(tmp_aln, split_events, 1, ref, bst, root, num_reads);
-
 				}
-				//	Parameter::Instance()->meassure_time(begin, " add split ");
-
 			}
 		}
+		//get next read:
 		mapped_file->parseReadFast(Parameter::Instance()->min_mq, tmp_aln);
+
 		num_reads++;
+
 		if (num_reads % 10000 == 0) {
-			curr = tmp_aln->getName();
+			//	curr = tmp_aln->getName();
 			cout << "\t\t# Processed reads: " << num_reads << endl;
-			if (curr.size() == prev.size() && strcmp(prev.c_str(), curr.c_str()) == 0) {
-				std::cerr << "Read occurred twice with primary alignment marked. Possibly no eof recognized in bam file." << std::endl;
-				break;
-			}
-			prev = curr;
+			/*(if (curr.size() == prev.size() && strcmp(prev.c_str(), curr.c_str()) == 0) {
+			 std::cerr << "Read occurred twice with primary alignment marked. Possibly no eof recognized in bam file." << std::endl;
+			 break;
+			 }
+			 prev = curr;*/
 		}
 	}
-
-//	cout << "Print tree:" << std::endl;
-//	bst.inorder(root);
 //filter and copy results:
 	std::cout << "Finalizing  .." << std::endl;
 	std::vector<Breakpoint *> points;
 	bst.get_breakpoints(root, points);
+	polish_points(points, ref);
 	for (int i = 0; i < points.size(); i++) {
 		if (should_be_stored(points[i])) {
+
 			if (points[i]->get_SVtype() & TRA) {
 				final.insert(points[i], root_final);
 			} else {
-
 				printer->printSV(points[i]);
 			}
 		}
 	}
-	bst.makeempty(root);
+	bst.clear(root);
 	if (Parameter::Instance()->genotype) {
 		fclose(ref_allel_reads);
 	}
 //	sweep->finalyze();
 	points.clear();
 	final.get_breakpoints(root_final, points);
+
+	size_t points_size = points.size();
+	for (size_t i = 0; i < points_size; i++) { // its not nice, but I may alter the length of the vector within the loop.
+		if (points[i]->get_SVtype() & TRA) {
+			vector<Breakpoint *> new_points;
+			detect_merged_svs(points[i]->get_coordinates(), ref, new_points);
+			if (!new_points.empty()) {							// I only allow for 1 split!!
+				points[i] = new_points[0];
+				points.push_back(new_points[1]);
+			}
+		}
+	}
+
 	for (size_t i = 0; i < points.size(); i++) {
 		if (points[i]->get_SVtype() & TRA) {
 			points[i]->calc_support();
@@ -251,25 +363,24 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 	}
 }
 
-void add_events(Alignment *& tmp, std::vector<str_event> events, short type, long ref_space, IntervallTree & bst, TNode *&root, long read_id) {
+void add_events(Alignment *& tmp, std::vector<str_event> events, short type, long ref_space, IntervallContainer & bst, TNode *&root, long read_id) {
 
 	bool flag = (strcmp(tmp->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
 	for (size_t i = 0; i < events.size(); i++) {
 		position_str svs;
 		read_str read;
-		read.type = 0;
+		if (events[i].is_noise) {
+			read.type = 2;
+		} else {
+			read.type = 0;
+		}
 		read.SV = events[i].type;
 
 		if (flag) {
 			std::cout << "ADD EVENT " << tmp->getName() << " " << tmp->getRefID() << " " << events[i].pos << " " << abs(events[i].length) << std::endl;
 		}
-		svs.start.min_pos = (long) events[i].pos;
-		svs.start.min_pos += ref_space;
-		svs.stop.max_pos = svs.start.min_pos;
-
-		if (!(events[i].type & INS)) { //for all events but not INS!
-			svs.stop.max_pos += events[i].length;
-		}
+		svs.start.min_pos = (long) events[i].pos + ref_space;
+		svs.stop.max_pos = svs.start.min_pos + events[i].length;
 
 		if (tmp->getStrand()) {
 			read.strand.first = (tmp->getStrand());
@@ -313,16 +424,25 @@ void add_events(Alignment *& tmp, std::vector<str_event> events, short type, lon
 			read.coordinates.first = svs.start.min_pos;
 			read.coordinates.second = svs.stop.max_pos;
 		}
+		/*if(read.SV & DEL){
+		 std::cout<<"ADD DEL: "<<svs.start.min_pos<< " "<<svs.stop.max_pos<<" "<<tmp->getName()<<std::endl;
+		 }*/
+		/*if(read.SV & INS){
+		 std::cout<<"ALN LEN: "<<events[i].length<<" Pos: "<<svs.start.min_pos<< " "<<svs.stop.max_pos<<" "<<tmp->getName()<<std::endl;
+		 }*/
 		read.id = read_id;
 		svs.support[tmp->getName()] = read;
+		svs.support[tmp->getName()].length = events[i].length;
 		Breakpoint * point = new Breakpoint(svs, events[i].length);
 		bst.insert(point, root);
+		//std::cout<<"Print:"<<std::endl;
+		//bst.print(root);
 	}
 }
 
-void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVector ref, IntervallTree & bst, TNode *&root, long read_id) {
+void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVector ref, IntervallContainer & bst, TNode *&root, long read_id) {
 	bool flag = (strcmp(tmp->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
-	//flag = true;
+
 	if (false) {
 		cout << "SPLIT: " << std::endl;
 		for (size_t i = 0; i < events.size(); i++) {
@@ -352,50 +472,42 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 					read.strand.first = !events[i - 1].strand;
 					read.strand.second = events[i].strand;
 				}
-				int len1 = 0;
-				int len2 = 0;
+				//	int len1 = 0;
+				//int len2 = 0;
 				svs.read_start = events[i - 1].read_pos_stop; // (short) events[i - 1].read_pos_start + (short) events[i - 1].length;
 				svs.read_stop = events[i].read_pos_start;
 				if (events[i - 1].strand) {
-					len1 = events[i - 1].pos;
-					len2 = events[i].pos - events[i].length;
+					//	len1 = events[i - 1].pos;
+					//	len2 = events[i].pos - events[i].length;
 					svs.start.min_pos = events[i - 1].pos + events[i - 1].length + get_ref_lengths(events[i - 1].RefID, ref);
 					svs.stop.max_pos = events[i].pos + get_ref_lengths(events[i].RefID, ref);
 				} else {
-					len1 = events[i].pos;
-					len2 = events[i - 1].pos - events[i - 1].length;
+					//	len1 = events[i].pos;
+					//	len2 = events[i - 1].pos - events[i - 1].length;
 					svs.start.min_pos = events[i].pos + events[i].length + get_ref_lengths(events[i].RefID, ref);
 					svs.stop.max_pos = events[i - 1].pos + get_ref_lengths(events[i - 1].RefID, ref);
 				}
 
 				if (flag) {
 					cout << "Debug: SV_Size: " << (svs.start.min_pos - svs.stop.max_pos) << " Ref_start: " << svs.start.min_pos - get_ref_lengths(events[i].RefID, ref) << " Ref_stop: " << svs.stop.max_pos - get_ref_lengths(events[i].RefID, ref) << " readstart: " << svs.read_start << " readstop: "
-							<< svs.read_stop << "readstart+len: " << len1 << " readstop+len: " << len2 << endl;
+							<< svs.read_stop << std::endl;
 				}
 
-				if ((svs.stop.max_pos - svs.start.min_pos) > 0 && ((svs.stop.max_pos - svs.start.min_pos) + (Parameter::Instance()->min_cigar_event) < (svs.read_stop - svs.read_start) && (svs.read_stop - svs.read_start) > (Parameter::Instance()->min_cigar_event * 2))) {
+				if ((svs.stop.max_pos - svs.start.min_pos) > -1 && ((svs.stop.max_pos - svs.start.min_pos) + (Parameter::Instance()->min_length) < (svs.read_stop - svs.read_start) && (svs.read_stop - svs.read_start) > (Parameter::Instance()->min_length * 2))) {
 					if (flag) {
 						cout << "INS: " << endl;
 					}
-					//read.SV = 'n'; //TODO redefine criteria!
 					read.SV |= INS;
-					/*	if (events[i - 1].strand) { //TODO check f
-					 svs.start.min_pos -=events[i - 1].length;
-					 }else{
-					 svs.start.min_pos -=events[i].length;
-					 }*/
-					//				cout<<"Split INS: "<<events[i - 1].length<<" "<<(svs.stop.max_pos - svs.start.min_pos)<<" "<<svs.read_stop - svs.read_start<<endl;
-				} else if ((svs.start.min_pos - svs.stop.max_pos) * -1 > (svs.read_stop - svs.read_start) + (Parameter::Instance()->min_cigar_event)) {
+				} else if ((svs.start.min_pos - svs.stop.max_pos) * -1 > (svs.read_stop - svs.read_start) + (Parameter::Instance()->min_length)) {
 					read.SV |= DEL;
 					if (flag) {
 						cout << "DEL" << endl;
 					}
-				} else if ((svs.start.min_pos - svs.stop.max_pos) > Parameter::Instance()->min_cigar_event) {
+				} else if ((svs.start.min_pos - svs.stop.max_pos) > Parameter::Instance()->min_length && (svs.read_start - svs.read_stop) < Parameter::Instance()->min_length) { //check with respect to the coords of reads!
 					read.SV |= DUP;
 					if (flag) {
 						cout << "DUP: " << endl;
 					}
-					//TODO ADDED &&(svs.read_stop - svs.read_start) > (Parameter::Instance()->min_cigar_event)
 				} else {
 					if (flag) {
 						cout << "N" << endl;
@@ -403,24 +515,41 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 					read.SV = 'n';
 				}
 			} else { // if first part of read is in a different direction as the second part-> INV
-				if (flag) {
-					cout << "INV" << endl;
-				}
-				/*if ((svs.start.min_pos - svs.stop.max_pos) > Parameter::Instance()->min_cigar_event) {
-				 //TODO =>DUP!
-				 std::cout << " SPLIT INV DUP!" << std::endl;
-				 }else{
-				 std::cout << "SPLIT INV"<<std::endl;
-				 }*/
+
 				read.strand.first = events[i - 1].strand;
 				read.strand.second = !events[i].strand;
-				read.SV |= INV;
-				if (events[i - 1].strand) {
-					svs.start.min_pos = events[i - 1].pos + events[i - 1].length + get_ref_lengths(events[i - 1].RefID, ref);
-					svs.stop.max_pos = (events[i].pos + events[i].length) + get_ref_lengths(events[i].RefID, ref);
+				if (overlaps(events[i - 1], events[i])) {
+					if (flag) {
+						std::cout << "Overlap curr: " << events[i].pos << " " << events[i].pos + events[i].length << " prev: " << events[i - 1].pos << " " << events[i - 1].pos + events[i - 1].length << " " << tmp->getName() << std::endl;
+					}
+					read.SV |= NEST;
+
+					if (events[i - 1].strand) {
+						svs.start.min_pos = events[i - 1].pos + events[i - 1].length + get_ref_lengths(events[i - 1].RefID, ref);
+						svs.stop.max_pos = (events[i].pos + events[i].length) + get_ref_lengths(events[i].RefID, ref);
+					} else {
+						svs.start.min_pos = events[i - 1].pos + get_ref_lengths(events[i - 1].RefID, ref);
+						svs.stop.max_pos = events[i].pos + get_ref_lengths(events[i].RefID, ref);
+					}
+
+					if (svs.start.min_pos > svs.stop.max_pos) {
+						long tmp = svs.start.min_pos;
+						svs.start.min_pos = svs.stop.max_pos;
+						svs.stop.max_pos = tmp;
+					}
+					//	if(flag){
+					//		std::cout<<"NEST: "<<svs.start.min_pos- get_ref_lengths(events[i - 1].RefID, ref) << " "<<svs.stop.max_pos - get_ref_lengths(events[i - 1].RefID, ref)<<" "<<tmp->getName()<<std::endl;
+					//	}
+					//	svs.stop.max_pos = svs.start.min_pos + Parameter::Instance()->min_length * 2;
 				} else {
-					svs.start.min_pos = events[i - 1].pos + get_ref_lengths(events[i - 1].RefID, ref);
-					svs.stop.max_pos = events[i].pos + get_ref_lengths(events[i].RefID, ref);
+					read.SV |= INV;
+					if (events[i - 1].strand) {
+						svs.start.min_pos = events[i - 1].pos + events[i - 1].length + get_ref_lengths(events[i - 1].RefID, ref);
+						svs.stop.max_pos = (events[i].pos + events[i].length) + get_ref_lengths(events[i].RefID, ref);
+					} else {
+						svs.start.min_pos = events[i - 1].pos + get_ref_lengths(events[i - 1].RefID, ref);
+						svs.stop.max_pos = events[i].pos + get_ref_lengths(events[i].RefID, ref);
+					}
 				}
 			}
 
@@ -447,21 +576,22 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 			read.SV |= TRA;
 		}
 
-		if (flag) {
-			std::cout << "SPLIT: " << TRANS_type(read.SV) << " start: " << svs.start.min_pos << " stop: " << svs.stop.max_pos; //- get_ref_lengths(events[i].RefID, ref);
-			if (events[i - 1].strand) {
-				std::cout << " +";
-			} else {
-				std::cout << " -";
-			}
-			if (events[i].strand) {
-				std::cout << " +";
-			} else {
-				std::cout << " -";
-			}
-			std::cout << " " << tmp->getName() << std::endl;
-		}
 		if (read.SV != 'n') {
+			if (flag) {
+				std::cout << "SPLIT: " << TRANS_type(read.SV) << " start: " << svs.start.min_pos - get_ref_lengths(events[i].RefID, ref) << " stop: " << svs.stop.max_pos - get_ref_lengths(events[i].RefID, ref);
+				if (events[i - 1].strand) {
+					std::cout << " +";
+				} else {
+					std::cout << " -";
+				}
+				if (events[i].strand) {
+					std::cout << " +";
+				} else {
+					std::cout << " -";
+				}
+				std::cout << " " << tmp->getName() << std::endl;
+				std::cout << "READ: " << svs.read_start << " " << svs.read_stop << " " << svs.read_start - svs.read_stop << std::endl;
+			}
 			//std::cout<<"split"<<std::endl;
 
 			svs.start.max_pos = svs.start.min_pos;
@@ -486,25 +616,26 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 				read.coordinates.first = svs.start.min_pos;
 				read.coordinates.second = svs.stop.max_pos;
 			}
-
+			/*if(read.SV & INS){
+			 std::cout<<"Split LEN: "<<abs(read.coordinates.second-read.coordinates.first)<<" Pos: "<<read.coordinates.first-get_ref_lengths(events[i - 1].RefID, ref)<<tmp->getName()<<std::endl;
+			 }*/
+			//if( abs(read.coordinates.second-read.coordinates.first)<10){
+			///	events[i].length=abs(read.coordinates.second-read.coordinates.first);//TODO try
+			//	std::cout<<"Split event ===1 "<<" "<<abs(read.coordinates.second-read.coordinates.first)<<" len: "<< events[i].length<<" Pos "<<events[i].pos <<" Name "<<tmp->getName() <<std::endl;
+			//	}
 			//pool out?
 			read.id = read_id;
 			svs.support[tmp->getName()] = read;
-			Breakpoint * point = new Breakpoint(svs, events[i].length);
-
+			svs.support[tmp->getName()].length = abs(read.coordinates.second - read.coordinates.first);
+			Breakpoint * point = new Breakpoint(svs, abs(read.coordinates.second - read.coordinates.first));
+			//std::cout<<"split ADD: " << <<" Name: "<<tmp->getName()<<" "<< svs.start.min_pos- get_ref_lengths(events[i].RefID, ref)<<"-"<<svs.stop.max_pos- get_ref_lengths(events[i].RefID, ref)<<std::endl;
 			bst.insert(point, root);
-			//	breakpoints_tmp1.push_back(pair<position_str,int> (svs, events[i].length)); TODO we could create 2 loops: 1st: collect evidence 2nd: further interpretation of complex Var
+			//		std::cout<<"Print:"<<std::endl;
+			//		bst.print(root);
 		}
 	}
 }
 
-void clarify(std::vector<Breakpoint *> & points) {
-//if WTF regions next to duplications-> delete!
-	/*for(size_t i=0;i<points.size();i++){
-
-	 }*/
-}
-
 void estimate_parameters(std::string read_filename) {
 	cout << "Estimating parameter..." << endl;
 	BamParser * mapped_file = 0;
@@ -525,19 +656,16 @@ void estimate_parameters(std::string read_filename) {
 	double avg_diffs_perwindow = 0;
 	vector<int> mis_per_window; //histogram over #differences
 	vector<int> scores;
-	std::string curr, prev = "";
-	double avg_dist=0;
+//	std::string curr, prev = "";
+	double avg_dist = 0;
 	while (!tmp_aln->getQueryBases().empty() && num < 1000) {				//1000
-
-		//I want to know avg. distance between events + #events within 100bp.
-
-		if (rand() % 100 < 10 && ((tmp_aln->getAlignment()->IsPrimaryAlignment()) && (!(tmp_aln->getAlignment()->AlignmentFlag & 0x800)))) {				//}&& tmp_aln->get_is_save()))) {
+		if (rand() % 100 < 20 && ((tmp_aln->getAlignment()->IsPrimaryAlignment()) && (!(tmp_aln->getAlignment()->AlignmentFlag & 0x800)))) {				//}&& tmp_aln->get_is_save()))) {
 			//1. check differences in window => min_treshold for scanning!
 			//2. get score ration without checking before hand! (above if!)
-			double dist=0;
+			double dist = 0;
 			vector<int> tmp = tmp_aln->get_avg_diff(dist);
-		//	std::cout<<"tmp: "<<dist<<std::endl;
-			avg_dist+=dist;
+			//std::cout<<dist<<std::endl;
+			avg_dist += dist;
 			for (size_t i = 0; i < tmp.size(); i++) {
 				while (tmp[i] + 1 > mis_per_window.size()) { //adjust length
 					mis_per_window.push_back(0);
@@ -553,21 +681,25 @@ void estimate_parameters(std::string read_filename) {
 			scores[score]++;
 			num++;
 		}
+
 		mapped_file->parseReadFast(Parameter::Instance()->min_mq, tmp_aln);
-		curr = tmp_aln->getName();
-		if (curr.size() == prev.size() && strcmp(prev.c_str(), curr.c_str()) == 0) {
-			std::cerr << "Read occurred twice with primary alignment marked. Possibly no eof recognized in bam file." << std::endl;
-			break;
-		}
-		prev = curr;
+		/*curr = tmp_aln->getName();
+		 if (curr.size() == prev.size() && strcmp(prev.c_str(), curr.c_str()) == 0) {
+		 std::cerr << "Read occurred twice with primary alignment marked. Possibly no eof recognized in bam file." << std::endl;
+		 break;
+		 }
+		 prev = curr;*/
+	}
+	if (num == 0) {
+		std::cerr << "No reads detected in " << Parameter::Instance()->bam_files[0] << std::endl;
+		exit(1);
 	}
-	avg_dist=avg_dist/num;
-	std::cout<<"Dist: "<<avg_dist<<std::endl;
-	Parameter::Instance()->avg_distance=avg_dist/2;
 	vector<int> nums;
 	size_t pos = 0;
-	Parameter::Instance()->window_thresh = 25;
+	Parameter::Instance()->max_dist_alns = floor(avg_dist / num) / 2;
+	Parameter::Instance()->window_thresh = 50;			//25;
 	if (!mis_per_window.empty()) {
+
 		for (size_t i = 0; i < mis_per_window.size(); i++) {
 			if (mis_per_window[i] != 0) {
 				//		std::cout << i << ": " << mis_per_window[i] << std::endl;
@@ -578,8 +710,7 @@ void estimate_parameters(std::string read_filename) {
 		}
 		pos = nums.size() * 0.95; //the highest 5% cutoff
 		if (pos <= nums.size()) {
-			std::cout << "thres: " << nums[pos] << " " << 25 << std::endl;
-			Parameter::Instance()->window_thresh = std::max(25, nums[pos]); //just in case we have too clean data! :)
+			Parameter::Instance()->window_thresh = std::max(Parameter::Instance()->window_thresh, nums[pos]); //just in case we have too clean data! :)
 		}
 		nums.clear();
 	}
@@ -591,8 +722,20 @@ void estimate_parameters(std::string read_filename) {
 	}
 	pos = nums.size() * 0.05; //the lowest 5% cuttoff
 	Parameter::Instance()->score_treshold = 2; //nums[pos]; //prev=2
+	std::cout << "\tMax dist between aln events: " << Parameter::Instance()->max_dist_alns << std::endl;
 	std::cout << "\tMax diff in window: " << Parameter::Instance()->window_thresh << std::endl;
 	std::cout << "\tMin score ratio: " << Parameter::Instance()->score_treshold << std::endl;
-	exit ;
 }
 
+bool overlaps(aln_str prev, aln_str curr) {
+
+	double ratio = 0;
+	double overlap = 0;
+
+	if (prev.pos + Parameter::Instance()->min_length < curr.pos + curr.length && prev.pos + prev.length - Parameter::Instance()->min_length > curr.pos) {
+		overlap = min((curr.pos + curr.length), (prev.pos + prev.length)) - max(prev.pos, curr.pos);
+		ratio = overlap / (double) min(curr.length, prev.length);
+	}
+
+	return (ratio > 0.4 && overlap > 200);
+}
