@@ -11,13 +11,18 @@
 #include <vector>
 
 #include "TNode.h"
-class IntervallTree {
+#include "IntervallContainer.h"
+
+
+
+class IntervallTree:public IntervallContainer {
 private:
 	int max(int, int);
 	TNode * srl(TNode *&);
 	TNode * drl(TNode *&);
 	TNode * srr(TNode *&);
 	TNode * drr(TNode *&);
+	void careful_screening(Breakpoint *& new_break, TNode *p);
 public:
 	void insert(Breakpoint * point, TNode *&);
 	void del(Breakpoint * point, TNode *&);
@@ -25,7 +30,7 @@ public:
 	void find(Breakpoint * point, TNode *&);
 	TNode * findmin(TNode*);
 	TNode * findmax(TNode*);
-	void makeempty(TNode *&);
+	void clear(TNode *&);
 	void copy(TNode * &, TNode *&);
 	TNode * nodecopy(TNode *&);
 	void preorder(TNode*);
@@ -35,6 +40,7 @@ public:
 	void get_breakpoints(TNode *p,std::vector<Breakpoint *> & points);
 	int nonodes(TNode*);
 	void collapse_intervalls(TNode *&p);
+	void print(TNode *p);
 };
 
 #endif /* TREE_INTERVALLTREE_H_ */
